@@ -175,6 +175,21 @@ func parseShiftAmount(shiftAmount string) (uint, error) {
 	return uint(value), nil
 }
 
+func parseTabAmount(tabAmount string) (uint, error) {
+	value, err := strconv.ParseUint(tabAmount, 10, 32)
+	if err != nil {
+		return 0, err
+	}
+
+	if value < 1 {
+		return 0, fmt.Errorf("Tab size must be at least 1")
+	}
+
+	// Let's add an upper bound as well if / when requested
+
+	return uint(value), nil
+}
+
 func parseMouseMode(mouseMode string) (twin.MouseMode, error) {
 	switch mouseMode {
 	case "auto":
@@ -369,6 +384,7 @@ func pagerFromArgs(
 		twin.NewStyledRune('>', twin.StyleDefault.WithAttr(twin.AttrReverse)),
 		"Shown when view can scroll right. One character with optional ANSI highlighting.", parseScrollHint)
 	shift := flagSetFunc(flagSet, "shift", 16, "Horizontal scroll `amount` >=1, defaults to 16", parseShiftAmount)
+	tabSize := flagSetFunc(flagSet, "tab-size", 8, "Number of spaces per tab stop, defaults to 8", parseTabAmount)
 	mouseMode := flagSetFunc(
 		flagSet,
 		"mousemode",
@@ -442,15 +458,6 @@ func pagerFromArgs(
 		flagSetArgs = []string{}
 	}
 
-	if len(flagSetArgs) > 1 && !stdoutIsRedirected {
-		fmt.Fprintln(os.Stderr, "ERROR: Expected exactly one filename, or data piped from stdin")
-		fmt.Fprintln(os.Stderr)
-		printCommandline(os.Stderr)
-		fmt.Fprintln(os.Stderr, "For help, run: \x1b[1mmoor --help\x1b[m")
-
-		os.Exit(1)
-	}
-
 	// Check that any input files can be opened
 	for _, inputFilename := range flagSetArgs {
 		// Need to check before newScreen() below, otherwise the screen
@@ -462,7 +469,7 @@ func pagerFromArgs(
 	}
 
 	if len(flagSetArgs) == 0 && !stdinIsRedirected {
-		fmt.Fprintln(os.Stderr, "ERROR: Filename or input pipe required (\"moor file.txt\")")
+		fmt.Fprintln(os.Stderr, "ERROR: Filename(s) or input pipe required (\"moor file.txt\")")
 		fmt.Fprintln(os.Stderr)
 		printCommandline(os.Stderr)
 		fmt.Fprintln(os.Stderr, "For help, run: \x1b[1mmoor --help\x1b[m")
@@ -484,15 +491,6 @@ func pagerFromArgs(
 		panic("Invariant broken: stdout is not a terminal")
 	}
 
-	if len(flagSetArgs) > 1 {
-		fmt.Fprintln(os.Stderr, "ERROR: Expected exactly one filename, or data piped from stdin")
-		fmt.Fprintln(os.Stderr)
-		printCommandline(os.Stderr)
-		fmt.Fprintln(os.Stderr, "For help, run: \x1b[1mmoor --help\x1b[m")
-
-		os.Exit(1)
-	}
-
 	formatter := formatters.TTY256
 	switch *terminalColorsCount {
 	case twin.ColorCount8:
@@ -503,29 +501,31 @@ func pagerFromArgs(
 		formatter = formatters.TTY16m
 	}
 
-	var readerImpl *reader.ReaderImpl
+	var readerImpls []*reader.ReaderImpl
 	shouldFormat := *reFormat
 	if stdinIsRedirected {
 		// Display input pipe contents
-		readerImpl, err = reader.NewFromStream("", os.Stdin, formatter, reader.ReaderOptions{Lexer: *lexer, ShouldFormat: shouldFormat})
+		readerImpl, err := reader.NewFromStream("", os.Stdin, formatter, reader.ReaderOptions{Lexer: *lexer, ShouldFormat: shouldFormat})
+
+		// If the user is doing "sudo something | moor" we can't show the UI until
+		// we start getting data, otherwise we'll mess up sudo's password prompt.
+		readerImpl.AwaitFirstByte()
+
 		if err != nil {
 			return nil, nil, chroma.Style{}, nil, logsRequested, err
 		}
+		readerImpls = append(readerImpls, readerImpl)
 	} else {
-		// Display the input file contents
-		if len(flagSetArgs) != 1 {
-			panic("Invariant broken: Expected exactly one filename")
-		}
-		readerImpl, err = reader.NewFromFilename(flagSetArgs[0], formatter, reader.ReaderOptions{Lexer: *lexer, ShouldFormat: shouldFormat})
-		if err != nil {
-			return nil, nil, chroma.Style{}, nil, logsRequested, err
+		// Display the input file(s) contents
+		for _, inputFilename := range flagSetArgs {
+			readerImpl, err := reader.NewFromFilename(inputFilename, formatter, reader.ReaderOptions{Lexer: *lexer, ShouldFormat: shouldFormat})
+			if err != nil {
+				return nil, nil, chroma.Style{}, nil, logsRequested, err
+			}
+			readerImpls = append(readerImpls, readerImpl)
 		}
 	}
 
-	// If the user is doing "sudo something | moor" we can't show the UI until
-	// we start getting data, otherwise we'll mess up sudo's password prompt.
-	readerImpl.AwaitFirstByte()
-
 	// We got the first byte, this means sudo is done (if it was used) and we
 	// can set up the UI.
 	screen, err := newScreen(*mouseMode, *terminalColorsCount)
@@ -533,7 +533,9 @@ func pagerFromArgs(
 		// Ref: https://github.com/walles/moor/issues/149
 		log.Info("Failed to set up screen for paging, pumping to stdout instead: ", err)
 
-		readerImpl.PumpToStdout()
+		for _, readerImpl := range readerImpls {
+			readerImpl.PumpToStdout()
+		}
 
 		return nil, nil, chroma.Style{}, nil, logsRequested, nil
 	}
@@ -545,9 +547,11 @@ func pagerFromArgs(
 		style = **styleOption
 	}
 	log.Debug("Using style <", style.Name, ">")
-	readerImpl.SetStyleForHighlighting(style)
+	for _, readerImpl := range readerImpls {
+		readerImpl.SetStyleForHighlighting(style)
+	}
 
-	pager := internal.NewPager(readerImpl)
+	pager := internal.NewPager(readerImpls...)
 	pager.WrapLongLines = *wrap
 	pager.ShowLineNumbers = !*noLineNumbers
 	pager.ShowStatusBar = !*noStatusBar
@@ -560,6 +564,7 @@ func pagerFromArgs(
 	pager.ScrollLeftHint = *scrollLeftHint
 	pager.ScrollRightHint = *scrollRightHint
 	pager.SideScrollAmount = int(*shift)
+	pager.TabSize = int(*tabSize)
 
 	pager.TargetLine = targetLine
 	if *follow && pager.TargetLine == nil {
